@@ -4,17 +4,14 @@ from __future__ import print_function
 
 import compas
 
+from .core import *  # noqa: F401 F403
 from ._network import *  # noqa: F401 F403
 
-from .operations import *  # noqa: F401 F403
-if not compas.IPY:
-    from .matrices import *  # noqa: F401 F403
-
 from .combinatorics import *  # noqa: F401 F403
 from .complementarity import *  # noqa: F401 F403
 from .duality import *  # noqa: F401 F403
 from .explode import *  # noqa: F401 F403
-from .parallelisation import *  # noqa: F401 F403
+# from .parallelisation import *  # noqa: F401 F403
 
 if not compas.IPY:
     from .planarity_ import *  # noqa: F401 F403
