@@ -5,14 +5,14 @@ from __future__ import division
 from compas.topology import connected_components
 
 __all__ = [
-    'network_disconnected_vertices',
+    'network_disconnected_nodes',
     'network_disconnected_edges',
     'network_explode'
 ]
 
 
-def network_disconnected_vertices(network):
-    """Get the disconnected vertex groups in a network.
+def network_disconnected_nodes(network):
+    """Get the disconnected node groups in a network.
 
     Parameters
     ----------
@@ -22,10 +22,8 @@ def network_disconnected_vertices(network):
     Returns
     -------
     list
-        The list of disconnected vertex groups.
-
+        The list of disconnected node groups.
     """
-
     return connected_components(network.adjacency)
 
 
@@ -41,16 +39,13 @@ def network_disconnected_edges(network):
     -------
     parts : list
         The list of disconnected edge groups.
-
     """
-
-    parts = network_disconnected_vertices(network)
-
-    return [[(u, v) for u in part for v in network.vertex_neighbors(u) if u < v] for part in parts]
+    components = network_disconnected_nodes(network)
+    return [[(u, v) for u in component for v in network.neighbors(u) if u < v] for component in components]
 
 
 def network_explode(network, cls=None):
-    """Explode a network into its disconnected parts.
+    """Explode a network into its connected components.
 
     Parameters
     ----------
@@ -61,25 +56,20 @@ def network_explode(network, cls=None):
     -------
     exploded_networks : list
         The list of the networks from the exploded network parts.
-
     """
-
     if cls is None:
         cls = type(network)
 
-    parts = network_disconnected_edges(network)
-
     exploded_networks = []
 
+    parts = network_disconnected_edges(network)
+
     for part in parts:
-
-        vertex_keys = list(set([vkey for edge in part for vkey in edge]))
-        vertices = [network.vertex_coordinates(vkey) for vkey in vertex_keys]
-
-        key_to_index = {vkey: i for i, vkey in enumerate(vertex_keys)}
-        edges = [(key_to_index[u], key_to_index[v]) for u, v in part]
-
-        exploded_networks.append(cls.from_vertices_and_edges(vertices, edges))
+        keys = list(set([key for edge in part for key in edge]))
+        nodes = [network.node_coordinates(key) for key in keys]
+        key_index = {key: index for index, key in enumerate(keys)}
+        edges = [(key_index[u], key_index[v]) for u, v in part]
+        exploded_networks.append(cls.from_nodes_and_edges(nodes, edges))
 
     return exploded_networks
 
@@ -92,7 +82,7 @@ if __name__ == "__main__":
 
     from compas.datastructures import Network
 
-    vertices = [
+    nodes = [
         [0.0, 0.0, 0.0],
         [1.0, 0.0, 0.0],
         [2.0, 0.0, 0.0],
@@ -106,8 +96,8 @@ if __name__ == "__main__":
         (3, 4),
     ]
 
-    network = Network.from_vertices_and_edges(vertices, edges)
+    network = Network.from_nodes_and_edges(nodes, edges)
 
-    print(network_disconnected_vertices(network))
+    print(network_disconnected_nodes(network))
     print(network_disconnected_edges(network))
     print(network_explode(network))
