@@ -29,8 +29,47 @@ class OBJ(object):
     """
 
     def __init__(self, filepath, precision=None):
-        self.reader = OBJReader(filepath)
-        self.parser = OBJParser(self.reader, precision=precision)
+        self.filepath = filepath
+        self.precision = precision
+
+        self._is_parsed = False
+        self._reader = None
+        self._parser = None
+
+    def read(self):
+        self._reader = OBJReader(self.filepath)
+        self._parser = OBJParser(self._reader, precision=self.precision)
+        self._is_parsed = True
+
+        self._reader.open()
+        self._reader.pre()
+        self._reader.read()
+        self._reader.post()
+        self._parser.parse()
+
+    @property
+    def reader(self):
+        if not self._is_parsed:
+            self.read()
+        return self._reader
+
+    @property
+    def parser(self):
+        if not self._is_parsed:
+            self.read()
+        return self._parser
+
+    @property
+    def vertices(self):
+        return self.parser.vertices
+
+    @property
+    def lines(self):
+        return self.parser.lines
+
+    @property
+    def faces(self):
+        return self.parser.faces
 
 
 class OBJReader(object):
@@ -103,10 +142,10 @@ class OBJReader(object):
         self.objects = {}
         self.group = None
         # open file path and read
-        self.open()
-        self.pre()
-        self.read()
-        self.post()
+        # self.open()
+        # self.pre()
+        # self.read()
+        # self.post()
 
     def open(self):
         if self.filepath.startswith('http'):
@@ -314,7 +353,7 @@ class OBJParser(object):
         self.surfaces = None
         self.groups = None
         self.objects = None
-        self.parse()
+        # self.parse()
 
     def parse(self):
         index_key = OrderedDict()
