@@ -2,19 +2,41 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-from compas.geometry.basic import scale_vector
-from compas.geometry.basic import normalize_vector
-from compas.geometry.basic import add_vectors
-from compas.geometry.basic import subtract_vectors
+from math import factorial
 
+from compas.geometry._primitives import Primitive
 from compas.geometry._primitives import Point
 from compas.geometry._primitives import Vector
 
-from compas.utilities import binomial_coefficient
 
 __all__ = ['Bezier']
 
 
+def binomial_coefficient(n, k):
+    """Returns the binomial coefficient of the :math:`x^k` term in the
+    polynomial expansion of the binomial power :math:`(1 + x)^n`.
+
+    Notes
+    -----
+    Arranging binomial coefficients into rows for successive values of `n`,
+    and in which `k` ranges from 0 to `n`, gives a triangular array known as
+    Pascal's triangle.
+
+    Parameters
+    ----------
+    n : int
+        The number of terms.
+    k : int
+        The index of the coefficient.
+
+    Returns
+    -------
+    int
+        The coefficient.
+    """
+    return int(factorial(n) / float(factorial(k) * factorial(n - k)))
+
+
 def bernstein(n, k, t):
     """k:sup:`th` of `n` + 1 Bernstein basis polynomials of degree `n`. A
     weighted linear combination of these basis polynomials is called a Bernstein
@@ -39,6 +61,10 @@ def bernstein(n, k, t):
     float
         The value of the Bernstein basis polynomial at `t`.
 
+    Examples
+    --------
+    >>> bernstein(3, 2, 0.5)
+    0.375
     """
     if k < 0:
         return 0
@@ -47,15 +73,11 @@ def bernstein(n, k, t):
     return binomial_coefficient(n, k) * t ** k * (1 - t) ** (n - k)
 
 
-class BezierException(Exception):
-    pass
-
-
-class Bezier(object):
+class Bezier(Primitive):
     """A Bezier curve.
 
-    A Bezier curve of degree `n` is a linear combination of `n` + 1 Bernstein
-    basis polynomials of degree `n`.
+    A Bezier curve of degree ``n`` is a linear combination of ``n + 1`` Bernstein
+    basis polynomials of degree ``n``.
 
     Parameters
     ----------
@@ -64,31 +86,40 @@ class Bezier(object):
 
     Attributes
     ----------
-    points : list
-        The control points.
-    degree : int
-        The degree of the curve.
+    data : dict
+        The dictionary representation of the curve.
+    points : list of :class:`compas.geometry.Point`
+        The control points of the curve.
+    degree : int, read-only
+        The curve degree.
 
+    Examples
+    --------
+    >>> curve = Bezier([[0.0, 0.0, 0.0], [0.5, 1.0, 0.0], [1.0, 0.0, 0.0]])
+    >>> curve.degree
+    2
     """
+
+    __module__ = "compas.geometry"
+
+    __slots__ = ["_points"]
+
     def __init__(self, points):
         self._points = []
         self.points = points
 
+    @property
+    def data(self):
+        """dict: The data dictionary that represents the curve."""
+        return {'points': [list(point) for point in self.points]}
+
+    @data.setter
+    def data(self, data):
+        self.points = data['points']
+
     @property
     def points(self):
-        """The control points.
-
-        Parameters
-        ----------
-        points : sequence
-            A sequence of control point locations in 3d space.
-
-        Returns
-        -------
-        list
-            A list of ``Point`` objects.
-
-        """
+        """list of :class:`compas.geometry.Point`: The control points."""
         return self._points
 
     @points.setter
@@ -98,10 +129,22 @@ class Bezier(object):
 
     @property
     def degree(self):
-        """The degree of the curve."""
+        """int (read-only): The degree of the curve."""
         return len(self.points) - 1
 
-    def compute_point(self, t):
+    # ==========================================================================
+    # constructors
+    # ==========================================================================
+
+    @classmethod
+    def from_data(cls, data):
+        return cls(data['points'])
+
+    # ==========================================================================
+    # methods
+    # ==========================================================================
+
+    def point(self, t):
         """Compute a point on the curve.
 
         Parameters
@@ -114,6 +157,13 @@ class Bezier(object):
         Point
             the corresponding point on the curve.
 
+        Examples
+        --------
+        >>> curve = Bezier([[0.0, 0.0, 0.0], [0.5, 1.0, 0.0], [1.0, 0.0, 0.0]])
+        >>> curve.point(0.0)
+        Point(0.000, 0.000, 0.000)
+        >>> curve.point(1.0)
+        Point(1.000, 0.000, 0.000)
         """
         n = self.degree
         point = Point(0, 0, 0)
@@ -122,7 +172,25 @@ class Bezier(object):
             point += p * b
         return point
 
-    def compute_tangent(self, t):
+    def tangent(self, t):
+        """Compute the tangent vector at a point on the curve.
+
+        Parameters
+        ----------
+        t : float
+            The value of the curve parameter. Must be between 0 and 1.
+
+        Returns
+        -------
+        Vector
+            The corresponding tangent vector.
+
+        Examples
+        --------
+        >>> curve = Bezier([[0.0, 0.0, 0.0], [0.5, 1.0, 0.0], [1.0, 0.0, 0.0]])
+        >>> curve.tangent(0.5)
+        Vector(1.000, 0.000, 0.000)
+        """
         n = self.degree
         v = Vector(0, 0, 0)
         for i, p in enumerate(self.points):
@@ -133,7 +201,7 @@ class Bezier(object):
         v.unitize()
         return v
 
-    def compute_locus(self, resolution=100):
+    def locus(self, resolution=100):
         """Compute the locus of all points on the curve.
 
         Parameters
@@ -145,33 +213,26 @@ class Bezier(object):
         Returns
         -------
         list
+            Points along the curve.
 
+        Examples
+        --------
+        >>> curve = Bezier([[0.0, 0.0, 0.0], [0.5, 1.0, 0.0], [1.0, 0.0, 0.0]])
+        >>> points = curve.locus(10)
+        >>> len(points) == 10
+        True
+        >>> points[0]
+        Point(0.000, 0.000, 0.000)
+        >>> points[-1]
+        Point(1.000, 0.000, 0.000)
         """
         locus = []
         divisor = float(resolution - 1)
         for i in range(resolution):
             t = i / divisor
-            locus.append(self.compute_point(t))
+            locus.append(self.point(t))
         return locus
 
-    def draw(self, params=None):
-        import matplotlib.pyplot as plt
-        locus = self.compute_locus()
-        x, y, _ = zip(*locus)
-        plt.plot(x, y, '-b')
-        x, y, _ = zip(* self.points)
-        plt.plot(x, y, 'ro')
-        if params is not None:
-            for t in params:
-                p0 = self.compute_point(t)
-                v = self.compute_tangent(t)
-                p1 = p0 + v
-                plt.plot([p0[0], p1[0]], [p0[1], p1[1]], '-k')
-                plt.plot([p0[0]], [p0[1]], 'ok')
-        ax = plt.gca()
-        ax.set_aspect('equal')
-        plt.show()
-
 
 # ==============================================================================
 # Main
@@ -179,5 +240,5 @@ class Bezier(object):
 
 if __name__ == '__main__':
 
-    curve = Bezier([[0, 0, 0], [1, -1, 0], [2, +1, 0], [3, 0, 0]])
-    curve.draw(params=[0.1, 0.2, 0.3, 0.4, 0.5])
+    import doctest
+    doctest.testmod(globs=globals())
