@@ -2,12 +2,14 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
+from compas.geometry._primitives import Primitive
 
 __all__ = ['Spline']
 
 
-class Spline(object):
+class Spline(Primitive):
     """"""
+
     def __init__(self):
         self.segments = []
 
