@@ -4,10 +4,9 @@ from __future__ import print_function
 
 import compas
 
-from .bbox import *
-
+from .bbox import *  # noqa: F401 F403
 if not compas.IPY:
-    from .bbox_numpy import *
+    from .bbox_numpy import *  # noqa: F401 F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
