@@ -147,11 +147,8 @@ if __name__ == "__main__":
 
     from compas.datastructures import Mesh
     from compas.datastructures import mesh_unify_cycles
-    from compas.datastructures import mesh_flip_cycles
     from compas_viewers import MeshViewer
 
-    from compas.topology import unify_cycles
-
     radius = 5
     origin = (0., 0., 0.)
     count = 0
@@ -173,15 +170,10 @@ if __name__ == "__main__":
 
     vertices = [points[index] for index in vertices]
     faces = [[i_index[i] for i in face] for face in faces]
-    # faces = unify_cycles(vertices, faces)
 
     mesh = Mesh.from_vertices_and_faces(vertices, faces)
-
     mesh_unify_cycles(mesh)
-    # mesh_flip_cycles(mesh)
 
     viewer = MeshViewer()
-
     viewer.mesh = mesh
-
     viewer.show()
