@@ -2,8 +2,6 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-
-from .kdtree import *
-
+from .kdtree import *  # noqa: F401 F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
