@@ -150,21 +150,16 @@ def voronoi_from_points_numpy(points):
 # ==============================================================================
 
 if __name__ == "__main__":
+    from compas.datastructures import Mesh
+    from compas.geometry import pointcloud_xy
+    from compas_plotters import MeshPlotter
 
-    pass
+    points = pointcloud_xy(10, (0, 50))
+    faces = delaunay_from_points_numpy(points)
 
-    # from compas.datastructures import Mesh
-    # from compas.geometry import pointcloud_xy
-    # from compas_plotters import MeshPlotter
+    delaunay = Mesh.from_vertices_and_faces(points, faces)
 
-    # points = pointcloud_xy(20, (0, 50))
-    # faces = delaunay_from_points_numpy(points)
-
-    # delaunay = Mesh.from_vertices_and_faces(points, faces)
-
-    # plotter = MeshPlotter(delaunay, figsize=(12, 8))
-
-    # plotter.draw_vertices(radius=0.1)
-    # plotter.draw_faces()
-
-    # plotter.show()
+    plotter = MeshPlotter(delaunay, figsize=(8, 5))
+    plotter.draw_vertices(radius=0.1)
+    plotter.draw_faces()
+    plotter.show()
