@@ -27,7 +27,7 @@ from .artist import Artist
 
 from .pointartist import PointArtist
 from .vectorartist import VectorArtist
-from .segmentartist import SegmentArtist
+from .segmentartist import SegmentArtist  # noqa: F401
 from .lineartist import LineArtist
 
 Artist.register(Point, PointArtist)
