@@ -42,6 +42,7 @@ Primitive Artists
 
     PointArtist
     LineArtist
+    PolylineArtist
     FrameArtist
 
 
@@ -73,6 +74,7 @@ from .artist import Artist
 from .primitiveartist import PrimitiveArtist  # noqa: F401
 from .pointartist import PointArtist
 from .lineartist import LineArtist
+from .polylineartist import PolylineArtist
 from .frameartist import FrameArtist
 from .networkartist import NetworkArtist  # noqa: F401
 from .meshartist import MeshArtist  # noqa: F401
@@ -80,6 +82,7 @@ from .volmeshartist import VolMeshArtist  # noqa: F401
 
 from compas.geometry import Frame
 from compas.geometry import Line
+from compas.geometry import Polyline
 from compas.geometry import Point
 
 from compas.datastructures import Mesh
@@ -87,6 +90,7 @@ from compas.datastructures import Mesh
 Artist.register(Point, PointArtist)
 Artist.register(Frame, FrameArtist)
 Artist.register(Line, LineArtist)
+Artist.register(Polyline, PolylineArtist)
 
 Artist.register(Mesh, MeshArtist)
 
