@@ -7,13 +7,13 @@ compas_rhino.inspectors
 
 .. autosummary::
     :toctree: generated/
+    :nosignatures:
 
     MeshVertexInspector
 
 """
 from __future__ import absolute_import
 
-from .meshinspector import *
-from .networkinspector import *
+from .meshinspector import *  # noqa: F401 F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
